# Legacy Software and Operating System support policy
It is the official policy of the Chik Blockchain project to end software support (in particular Python versions), as well as operating systems.

Chik blockchain project intends that if the original maintainer of a software or operating system no longer supports a given version, the Chik Blockchain project does not intend to continue providing support for it.

## Long-term support conflicts
If a long-term support version of an operating system uses a default Python version that has lost official support, we also intend to end support for that operating system version, so as to avoid issues with installing a new Python version via Chik install, which may break crucial operating system components.

## More information
For more information, please contact hello@chiknetwork.com or reach out on the community Discord.
